==> feezfuzz-0.1.1-py3-none-any.whl: feezfuzz/enums/instructions.py <==
INSTRUCTIONS = [
    ["!",  "say",                    ["id6", "int"]         ],
    ["C",  "setModel",               ["str"]                ],
    ["\"", "choice",                 ["int", "id6"]         ],
    ["#",  "waitForUser",            []                     ],
    ["$",  "label",                  ["int"]                ],
    ["&",  "setCamera",              ["int"]                ],
    ["%",  "exit",                   []                     ],
    ["'",  "wizform",                ["int", "int", "int"]  ],
    ["(",  "spell",                  ["int", "int", "int"]  ],
    ["8",  "else",                   []                     ],
    [")",  "changeWaypoint",         ["int", "int"]         ],
    ["*",  "fight",                  ["int", "int"]         ],
    ["+",  "lookAtPlayer",           ["int", "int"]         ],
    [",",  "changeDatabase",         ["id5"]                ],
    ["-",  "removeNpc",              []                     ],
    [".",  "catchWizform",           []                     ],
    ["0",  "killPlayer",             []                     ],
    ["5",  "tradingCurrency",        ["id4"]                ],
    ["2",  "tradingItem",            ["int", "id4"]         ],
    ["3",  "tradingSpell",           ["int", "id3"]         ],
    ["4",  "tradingWizform",         ["int", "id1"]         ],
    ["1",  "givePlayerCards",        ["int", "int", "int"]  ],
    ["B",  "setupGambling",          ["int", "int", "int"]  ],
    ["6",  "ifPlayerHasCards",       ["int", "int", "int"]  ],
    ["@",  "ifPlayerHasSpecials",    ["int", "int"]         ],
    ["=",  "ifTriggerIsActive",      ["int"]                ],
    ["9",  "removePlayerCards",      ["int", "int", "int"]  ],
    [":",  "moveSystem",             ["int", "int"]         ],
    ["?",  "movementSpeed",          ["int"]                ],
    [";",  "modifyWizform",          ["int", "int"]         ],
    ["<",  "lockUserInput",          ["int"]                ],
    [">",  "modifyTrigger",          ["int", "int", "int"]  ],
    ["A",  "playAnimation",          ["int", "int"]         ],
    ["D",  "ifIsWizform",            []                     ],
    ["E",  "startPrelude",           []                     ],
    ["F",  "npcWizFormEscapes",      []                     ],
  # ["G",  "dance",                  []                     ],
    ["H",  "setGlobal",              ["int", "int"]         ], # unclear
    ["I",  "beginIf_global",         ["int", "int"]         ], # unclear
    ["J",  "talk",                   ["id6"]                ],
    ["K",  "goto",                   ["int"]                ],
    ["L",  "gotoRandomLabel",        ["int", "int"]         ],
  # ["M",  "ask",                    []                     ],
    ["N",  "chafferWizForms",        ["id6", "id6", "id6"]  ],
    ["O",  "setNpcType",             ["int"]                ],
    ["P",  "deployNpcAtTrigger",     ["int", "id5"]         ], # requires special cases
    ["Q",  "delay",                  ["int"]                ],
    ["R",  "gotoLabelByRandom",      ["int", "int"]         ],
    ["S",  "ifCloseToWaypoint",      ["int"]                ],
    ["T",  "removeWizForms",         []                     ],
    ["U",  "ifNpcModifierHasValue",  ["int"]                ],
    ["V",  "setNpcModifier",         ["int", "int", "int"]  ],
    ["W",  "defaultWizForm",         ["int", "int", "int"]  ],
    ["X",  "idle",                   []                     ],
    ["Y",  "ifPlayerIsClose",        ["int"]                ],
    ["Z",  "ifNumberOfNpcsIs",       ["int", "id5"]         ],
    ["[",  "startEffect",            ["int", "int"]         ],
    ["\\", "setTalkLabels",          ["int", "int", "int"]  ],
    ["]",  "setCollision",           ["int"]                ],
    ["^",  "tradeWizform",           ["int"]                ],
    ["_",  "createDynamicItems",     ["int", "int", "int"]  ],
    ["`",  "playVideo",              ["int"]                ],
    ["a",  "removeNpcAtTrigger",     ["int"]                ],
    ["b",  "revive",                 []                     ],
    ["c",  "lookAtTrigger",          ["int", "int"]         ],
    ["d",  "ifTriggerIsEnabled",     ["int"]                ],
    ["e",  "playSound",              ["int"]                ],
    ["f",  "playInArena",            ["int"]                ],
    ["g",  "startActorEffect",       ["int"]                ],
    ["h",  "endActorEffect",         []                     ],
    ["i",  "createSceneObjects",     ["int"]                ],
  # ["j",  "evolveWizForm",          []                     ],
    ["k",  "removeBehavior",         ["int"]                ],
    ["l",  "unlockDoor",             ["int", "int"]         ],
    ["m",  "endGame",                []                     ],
    ["n",  "defaultDeck",            ["int", "int", "int"]  ],
    ["o",  "subGame",                ["int", "int", "int"]  ],
    ["p",  "modifyEffect",           ["int", "int", "int"]  ],
    ["q",  "playPlayerAnimation",    ["int", "int"]         ], # second arg unused
    ["s",  "playAmyVoice",           ["str"]                ],
    ["r",  "createDynamicModel",     ["int", "int", "int"]  ],
    ["t",  "deploySound",            ["int", "int"]         ],
    ["u",  "givePlayerPresent",      ["int"]                ],
    ["7",  "endIf",                  []                     ],
]

==> feezfuzz-0.1.3-py3-none-any.whl: feezfuzz/enums/instructions.py <==
INSTRUCTIONS = [
    ["!",  "say",                    ["id6", "int"]         ],
    ["C",  "setModel",               ["str"]                ],
    ["\"", "choice",                 ["int", "id6"]         ],
    ["#",  "waitForUser",            []                     ],
    ["$",  "label",                  ["int"]                ],
    ["&",  "setCamera",              ["int"]                ],
    ["%",  "exit",                   []                     ],
    ["'",  "wizform",                ["int", "int", "int"]  ],
    ["(",  "spell",                  ["int", "int", "int"]  ],
    ["8",  "else",                   []                     ],
    [")",  "changeWaypoint",         ["int", "int"]         ],
    ["*",  "fight",                  ["int", "int"]         ],
    ["+",  "lookAtPlayer",           ["int", "int"]         ],
    [",",  "changeDatabase",         ["id5"]                ],
    ["-",  "removeNpc",              []                     ],
    [".",  "catchWizform",           []                     ],
    ["0",  "killPlayer",             []                     ],
    ["5",  "tradingCurrency",        ["id4"]                ],
    ["2",  "tradingItem",            ["int", "id4"]         ],
    ["3",  "tradingSpell",           ["int", "id3"]         ],
    ["4",  "tradingWizform",         ["int", "id1"]         ],
    ["1",  "givePlayerCards",        ["int", "int", "int"]  ],
    ["B",  "setupGambling",          ["int", "int", "int"]  ],
    ["6",  "ifPlayerHasCards",       ["int", "int", "int"]  ],
    ["@",  "ifPlayerHasSpecials",    ["int", "int"]         ],
    ["=",  "ifTriggerIsActive",      ["int"]                ],
    ["9",  "removePlayerCards",      ["int", "int", "int"]  ],
    [":",  "moveSystem",             ["int", "int"]         ],
    ["?",  "movementSpeed",          ["int"]                ],
    [";",  "modifyWizform",          ["int", "int"]         ],
    ["<",  "lockUserInput",          ["int"]                ],
    [">",  "modifyTrigger",          ["int", "int", "int"]  ],
    ["A",  "playAnimation",          ["int", "int"]         ],
    ["D",  "ifIsWizform",            []                     ],
    ["E",  "startPrelude",           []                     ],
    ["F",  "npcWizFormEscapes",      []                     ],
  # ["G",  "dance",                  []                     ],
    ["H",  "setGlobal",              ["int", "int"]         ], # unclear
    ["I",  "beginIf_global",         ["int", "int"]         ], # unclear
    ["J",  "talk",                   ["id6"]                ],
    ["K",  "goto",                   ["int"]                ],
    ["L",  "gotoRandomLabel",        ["int", "int"]         ],
  # ["M",  "ask",                    []                     ],
    ["N",  "chafferWizForms",        ["id6", "id6", "id6"]  ],
    ["O",  "setNpcType",             ["int"]                ],
    ["P",  "deployNpcAtTrigger",     ["int", "id5"]         ], # requires special cases
    ["Q",  "delay",                  ["int"]                ],
    ["R",  "gotoLabelByRandom",      ["int", "int"]         ],
    ["S",  "ifCloseToWaypoint",      ["int"]                ],
    ["T",  "removeWizForms",         []                     ],
    ["U",  "ifNpcModifierHasValue",  ["int"]                ],
    ["V",  "setNpcModifier",         ["int", "int", "int"]  ],
    ["W",  "defaultWizForm",         ["int", "int", "int"]  ],
    ["X",  "idle",                   []                     ],
    ["Y",  "ifPlayerIsClose",        ["int"]                ],
    ["Z",  "ifNumberOfNpcsIs",       ["int", "id5"]         ],
    ["[",  "startEffect",            ["int", "int"]         ],
    ["\\", "setTalkLabels",          ["int", "int", "int"]  ],
    ["]",  "setCollision",           ["int"]                ],
    ["^",  "tradeWizform",           ["int"]                ],
    ["_",  "createDynamicItems",     ["int", "int", "int"]  ],
    ["`",  "playVideo",              ["int"]                ],
    ["a",  "removeNpcAtTrigger",     ["int"]                ],
    ["b",  "revive",                 []                     ],
    ["c",  "lookAtTrigger",          ["int", "int"]         ],
    ["d",  "ifTriggerIsEnabled",     ["int"]                ],
    ["e",  "playSound",              ["int"]                ],
    ["f",  "playInArena",            ["int", "int"]         ], # second arg unused
    ["g",  "startActorEffect",       ["int"]                ],
    ["h",  "endActorEffect",         []                     ],
    ["i",  "createSceneObjects",     ["int"]                ],
  # ["j",  "evolveWizForm",          []                     ],
    ["k",  "removeBehavior",         ["int"]                ],
    ["l",  "unlockDoor",             ["int", "int"]         ],
    ["m",  "endGame",                []                     ],
    ["n",  "defaultDeck",            ["int", "int", "int"]  ],
    ["o",  "subGame",                ["int", "int", "int"]  ],
    ["p",  "modifyEffect",           ["int", "int", "int"]  ],
    ["q",  "playPlayerAnimation",    ["int", "int"]         ], # second arg unused
    ["s",  "playAmyVoice",           ["str"]                ],
    ["r",  "createDynamicModel",     ["int", "int", "int"]  ],
    ["t",  "deploySound",            ["int", "int"]         ],
    ["u",  "givePlayerPresent",      ["int"]                ],
    ["7",  "endIf",                  []                     ],
]
